@@ -4,7 +4,7 @@ Coro::Select - a (slow but coro-aware) replacement for CORE::select
 
 =head1 SYNOPSIS
 
- use Coro::Select;          # replace select globally
+ use Coro::Select;          # replace select globally (be careful, see below)
  use Core::Select 'select'; # only in this module
  use Coro::Select ();       # use Coro::Select::select
 
@@ -19,12 +19,28 @@ non-blocking w.r.t. other coroutines.
 
 To be effective globally, this module must be C<use>'d before any other
 module that uses C<select>, so it should generally be the first module
-C<use>'d in the main program.
+C<use>'d in the main program. Note that overriding C<select> globally
+might actually cause problems, as some C<AnyEvent> backends use C<select>
+themselves, and asking AnyEvent to use Coro::Select, which in turn asks
+AnyEvent will not quite work.
 
 You can also invoke it from the commandline as C<perl -MCoro::Select>.
 
-Performance naturally isn't great, but unless you need very high select
-performance you normally won't notice the difference.
+To override select only for a single module (e.g. C<Net::DBus::Reactor>),
+use a code fragment like this to load it:
+
+   {
+      package Net::DBus::Reactor;
+      use Coro::Select qw(select);
+      use Net::DBus::Reactor;
+   }
+
+Performance naturally isn't great (every file descriptor must be dup'ed),
+but unless you need very high select performance you normally won't notice
+the difference.
+
+This implementation works fastest when only very few bits are set in the
+fd set(s).
 
 =over 4
 
@@ -34,13 +50,15 @@ package Coro::Select;
 
 use strict;
 
+use Errno;
+
 use Coro ();
 use AnyEvent ();
 use Coro::AnyEvent ();
 
 use base Exporter::;
 
-our $VERSION = 5.13;
+our $VERSION = 5.132;
 our @EXPORT_OK = "select";
 
 sub import {
@@ -67,17 +85,27 @@ sub select(;*$$$) { # not the correct prototype, but well... :()
       # AnyEvent does not do 'e', so replace it by 'r'
       for ([0, 'r', '<'], [1, 'w', '>'], [2, 'r', '<']) {
          my ($i, $poll, $mode) = @$_;
-         if (defined (my $vec = $_[$i])) {
+         if (defined $_[$i]) {
             my $rvec = \$_[$i];
-            for my $b (0 .. (8 * length $vec)) {
-               if (vec $vec, $b, 1) {
-                  (vec $$rvec, $b, 1) = 0;
-                  open my $fh, "$mode&=$b"
-                     or die "Coro::Select::fd2fh($b): $!";
+
+            # we parse the bitmask by first expanding it into
+            # a string of bits
+            for (unpack "b*", $$rvec) {
+               # and then repeatedly matching a regex against it
+               while (/1/g) {
+                  my $fd = (pos) - 1;
+
+                  (vec $$rvec, $fd, 1) = 0;
+
+                  # we need to dup(), unfortunately
+                  open my $fh, "$mode&$fd"
+                     or do { $! = Errno::EBADF; return -1 };
+
                   push @w,
+                     $fh,
                      AnyEvent->io (fh => $fh, poll => $poll, cb => sub {
-                        (vec $$rvec, $b, 1) = 1;
-                        $nfound++;
+                        (vec $$rvec, $fd, 1) = 1;
+                        ++$nfound;
                         $wakeup->();
                      });
                }
